==> qmmp_1.0.5.orig.tar.bz2: qmmp-1.0.5/src/plugins/Input/gme/translations/gme_plugin_gl_ES.ts <==
<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.0" language="gl_ES">
<context>
    <name>DecoderGmeFactory</name>
    <message>
        <location filename="../decodergmefactory.cpp" line="50"/>
        <source>GME Plugin</source>
        <translation>Engadido GME</translation>
    </message>
    <message>
        <location filename="../decodergmefactory.cpp" line="53"/>
        <source>Game Music Files</source>
        <translation>Game Music Files</translation>
    </message>
    <message>
        <location filename="../decodergmefactory.cpp" line="117"/>
        <source>About GME Audio Plugin</source>
        <translation>Sobre o engadido GME</translation>
    </message>
    <message>
        <location filename="../decodergmefactory.cpp" line="118"/>
        <source>Qmmp GME Audio Plugin</source>
        <translation>Engadido GME de Qmmp</translation>
    </message>
    <message>
        <location filename="../decodergmefactory.cpp" line="119"/>
        <source>This plugin uses Game_Music_Emu library to play game music files</source>
        <translation>Este engadido usa a librería Game_Music_Emu para reproducir ficheiros de xogo de música</translation>
    </message>
    <message>
        <location filename="../decodergmefactory.cpp" line="120"/>
        <source>Written by: Ilya Kotov &lt;forkotov02@hotmail.ru&gt;</source>
        <translation>Escrito por: Ilya Kotov &lt;forkotov02@hotmail.ru&gt;</translation>
    </message>
</context>
<context>
    <name>SettingsDialog</name>
    <message>
        <location filename="../settingsdialog.ui" line="14"/>
        <source>GME Plugin Settings</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../settingsdialog.ui" line="34"/>
        <source>Fadeout length:</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../settingsdialog.ui" line="44"/>
        <source>ms</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../settingsdialog.ui" line="57"/>
        <source>Enable fadeout</source>
        <translation type="unfinished"></translation>
    </message>
</context>
</TS>

==> qmmp_1.1.10.orig.tar.bz2: qmmp-1.1.10/src/plugins/Input/gme/translations/gme_plugin_gl_ES.ts <==
<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.0" language="gl_ES">
<context>
    <name>DecoderGmeFactory</name>
    <message>
        <location filename="../decodergmefactory.cpp" line="50"/>
        <source>GME Plugin</source>
        <translation>Engadido GME</translation>
    </message>
    <message>
        <location filename="../decodergmefactory.cpp" line="53"/>
        <source>Game Music Files</source>
        <translation>Game Music Files</translation>
    </message>
    <message>
        <location filename="../decodergmefactory.cpp" line="117"/>
        <source>About GME Audio Plugin</source>
        <translation>Sobre o engadido GME</translation>
    </message>
    <message>
        <location filename="../decodergmefactory.cpp" line="118"/>
        <source>Qmmp GME Audio Plugin</source>
        <translation>Engadido GME de Qmmp</translation>
    </message>
    <message>
        <location filename="../decodergmefactory.cpp" line="119"/>
        <source>This plugin uses Game_Music_Emu library to play game music files</source>
        <translation>Este engadido usa a librería Game_Music_Emu para reproducir ficheiros de xogo de música</translation>
    </message>
    <message>
        <location filename="../decodergmefactory.cpp" line="120"/>
        <source>Written by: Ilya Kotov &lt;forkotov02@hotmail.ru&gt;</source>
        <translation>Escrito por: Ilya Kotov &lt;forkotov02@hotmail.ru&gt;</translation>
    </message>
</context>
<context>
    <name>SettingsDialog</name>
    <message>
        <location filename="../settingsdialog.ui" line="14"/>
        <source>GME Plugin Settings</source>
        <translation>Opcións engadido GME</translation>
    </message>
    <message>
        <location filename="../settingsdialog.ui" line="34"/>
        <source>Fadeout length:</source>
        <translation>Duración do fundido:</translation>
    </message>
    <message>
        <location filename="../settingsdialog.ui" line="44"/>
        <source>ms</source>
        <translation>ms</translation>
    </message>
    <message>
        <location filename="../settingsdialog.ui" line="57"/>
        <source>Enable fadeout</source>
        <translation>Habilitar fundido</translation>
    </message>
</context>
</TS>
